aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Kabui2021-12-06 14:07:57 +0300
committerBonfaceKilz2021-12-13 15:48:00 +0300
commit99d9c213f1c825af5b5bf6007521894b29131ba8 (patch)
tree5799a2497f5c50ab7cfbeeab96515005eaee871c
parent34f57439476959ca1fb8d149647ecb2b1720908c (diff)
downloadgenenetwork2-99d9c213f1c825af5b5bf6007521894b29131ba8.tar.gz
add new endpoint:for test gn3 wgcna
-rw-r--r--wqflask/wqflask/views.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/wqflask/wqflask/views.py b/wqflask/wqflask/views.py
index 23b4e07a..f2c539d1 100644
--- a/wqflask/wqflask/views.py
+++ b/wqflask/wqflask/views.py
@@ -339,9 +339,11 @@ def wcgna_setup():
return render_template("wgcna_setup.html", **request.form)
-@app.route("/wgcna_results", methods=('POST',))
-def wcgna_results():
- """call the gn3 api to get wgcna response data"""
+
+
+@app.route("/test/wgcna_results", methods=('POST',))
+def test_wcgna_results():
+ """test call the gn3 api to get wgcna response data"""
results = run_wgcna(dict(request.form))
return render_template("test_wgcna_results.html", **results)